@@ -247,6 +247,8 @@ PyAPI_FUNC(PyObject *) PyEval_CallObjectWithKeywords(PyObject *arg0, PyObject *a
 PyAPI_FUNC(PyObject *) PyEval_EvalCode(PyCodeObject *arg0, PyObject *arg1, PyObject *arg2);
 #define PyEval_GetBuiltins PyPyEval_GetBuiltins
 PyAPI_FUNC(PyObject *) PyEval_GetBuiltins(void);
+#define PyEval_GetFrame PyPyEval_GetFrame
+PyAPI_FUNC(PyFrameObject *) PyEval_GetFrame(void);
 #define PyEval_GetGlobals PyPyEval_GetGlobals
 PyAPI_FUNC(PyObject *) PyEval_GetGlobals(void);
 #define PyEval_GetLocals PyPyEval_GetLocals
@@ -947,6 +949,10 @@ PyAPI_FUNC(int) Py_IsInitialized(void);
 PyAPI_FUNC(void) Py_LeaveRecursiveCall(void);
 #define Py_MakePendingCalls PyPy_MakePendingCalls
 PyAPI_FUNC(int) Py_MakePendingCalls(void);
+#define Py_ReprEnter PyPy_ReprEnter
+PyAPI_FUNC(int) Py_ReprEnter(PyObject *arg0);
+#define Py_ReprLeave PyPy_ReprLeave
+PyAPI_FUNC(void) Py_ReprLeave(PyObject *arg0);
 #define Py_SetRecursionLimit PyPy_SetRecursionLimit
 PyAPI_FUNC(void) Py_SetRecursionLimit(int arg0);
 #define Py_UNICODE_COPY PyPy_UNICODE_COPY
@@ -1215,6 +1221,8 @@ PyAPI_DATA(PyTypeObject) PyMemberDescr_Type;
 PyAPI_DATA(PyTypeObject) PyMethodDescr_Type;
 #define PyWrapperDescr_Type PyPyWrapperDescr_Type
 PyAPI_DATA(PyTypeObject) PyWrapperDescr_Type;
+#define PyBufferable_Type PyPyBufferable_Type
+PyAPI_DATA(PyTypeObject) PyBufferable_Type;
 
 #undef Signed    /* xxx temporary fix */
 #undef Unsigned  /* xxx temporary fix */
